format_bib = function(...) {
  str = vapply(list(...), function(entry) tools::toRd(bibentries[[entry]]), FUN.VALUE = "")
  paste0(str, collapse = "\n\n")
}

#' @importFrom utils bibentry
bibentries = c(
  chawla_2002 = bibentry("article",
    doi       = "10.1613/jair.953",
    year      = "2002",
    month     = "jun",
    publisher = "{AI} Access Foundation",
    volume    = "16",
    pages     = "321--357",
    author    = "N. V. Chawla and K. W. Bowyer and L. O. Hall and W. P. Kegelmeyer",
    title     = "{SMOTE}: Synthetic Minority Over-sampling Technique",
    journal   = "Journal of Artificial Intelligence Research"
  ),

  ding_2010   = bibentry("article",
    author    = "Yufeng Ding and Jeffrey S. Simonoff",
    title     = "An Investigation of Missing Data Methods for Classification Trees Applied to Binary Response Data",
    journal   = "Journal of Machine Learning Research",
    year      = "2010",
    volume    = "11",
    number    = "6",
    pages     = "131-170",
    url       = "https://jmlr.org/papers/v11/ding10a.html"
  ),

  ledell_2015 = bibentry("phdthesis",
    title     = "Scalable Ensemble Learning and Computationally Efficient Variance Estimation",
    author    = "LeDell, Erin",
    year      = "2015",
    school    = "UC Berkeley"
  )
)
